project

package
v2.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2026 License: Apache-2.0 Imports: 39 Imported by: 0

Documentation

Overview

Package project contains commands for working with Crossplane projects.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Cmd

type Cmd struct {
	Init  initCmd  `cmd:"" help:"Initialize a new project."`
	Build buildCmd `cmd:"" help:"Build a project into Crossplane packages."`
	Push  pushCmd  `cmd:"" help:"Push a built project to an OCI registry."`
	Run   runCmd   `cmd:"" help:"Build and run a project in a local dev control plane."`
	Stop  stopCmd  `cmd:"" help:"Tear down a local dev control plane."`
}

Cmd contains project subcommands.

Jump to