Documentation
¶
Overview ¶
Package project contains commands for working with Crossplane projects.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cmd ¶
type Cmd struct {
Init initCmd `cmd:"" help:"Initialize a new project."`
Build buildCmd `cmd:"" help:"Build a project into Crossplane packages."`
Push pushCmd `cmd:"" help:"Push a built project to an OCI registry."`
Run runCmd `cmd:"" help:"Build and run a project in a local dev control plane."`
Stop stopCmd `cmd:"" help:"Tear down a local dev control plane."`
}
Cmd contains project subcommands.
Click to show internal directories.
Click to hide internal directories.